@@ -84,31 +84,31 @@ impl Display for Architecture {
 impl AsRef<str> for Architecture {
     fn as_ref(&self) -> &str {
         match self {
-            Architecture::All => "all",
-            Architecture::Alpha => "alpha",
-            Architecture::Amd64 => "amd64",
-            Architecture::Arc => "arc",
-            Architecture::Arm64 => "arm64",
-            Architecture::Armel => "armel",
-            Architecture::Armhf => "armhf",
-            Architecture::Hppa => "hppa",
-            Architecture::HurdAmd64 => "hurd-amd64",
-            Architecture::HurdI386 => "hurd-i386",
-            Architecture::I386 => "i386",
-            Architecture::Ia64 => "ia64",
-            Architecture::Loong64 => "loong64",
-            Architecture::M68k => "m68k",
-            Architecture::Mips64el => "mips64el",
-            Architecture::Mipsel => "mipsel",
-            Architecture::PowerPC => "powerpc",
-            Architecture::Ppc64 => "ppc64",
-            Architecture::Ppc64el => "ppc64el",
-            Architecture::Riscv64 => "riscv64",
-            Architecture::S390x => "s390x",
-            Architecture::Sh4 => "sh4",
-            Architecture::Sparc64 => "sparc64",
-            Architecture::X32 => "x32",
-            Architecture::Source => "source",
+            Self::All => "all",
+            Self::Alpha => "alpha",
+            Self::Amd64 => "amd64",
+            Self::Arc => "arc",
+            Self::Arm64 => "arm64",
+            Self::Armel => "armel",
+            Self::Armhf => "armhf",
+            Self::Hppa => "hppa",
+            Self::HurdAmd64 => "hurd-amd64",
+            Self::HurdI386 => "hurd-i386",
+            Self::I386 => "i386",
+            Self::Ia64 => "ia64",
+            Self::Loong64 => "loong64",
+            Self::M68k => "m68k",
+            Self::Mips64el => "mips64el",
+            Self::Mipsel => "mipsel",
+            Self::PowerPC => "powerpc",
+            Self::Ppc64 => "ppc64",
+            Self::Ppc64el => "ppc64el",
+            Self::Riscv64 => "riscv64",
+            Self::S390x => "s390x",
+            Self::Sh4 => "sh4",
+            Self::Sparc64 => "sparc64",
+            Self::X32 => "x32",
+            Self::Source => "source",
         }
     }
 }
@@ -118,31 +118,31 @@ impl TryFrom<&str> for Architecture {
 
     fn try_from(value: &str) -> Result<Self, Self::Error> {
         match value {
-            "all" => Ok(Architecture::All),
-            "alpha" => Ok(Architecture::Alpha),
-            "amd64" => Ok(Architecture::Amd64),
-            "arc" => Ok(Architecture::Arc),
-            "arm64" => Ok(Architecture::Arm64),
-            "armel" => Ok(Architecture::Armel),
-            "armhf" => Ok(Architecture::Armhf),
-            "hppa" => Ok(Architecture::Hppa),
-            "hurd-amd64" => Ok(Architecture::HurdAmd64),
-            "hurd-i386" => Ok(Architecture::HurdI386),
-            "i386" => Ok(Architecture::I386),
-            "ia64" => Ok(Architecture::Ia64),
-            "loong64" => Ok(Architecture::Loong64),
-            "m68k" => Ok(Architecture::M68k),
-            "mips64el" => Ok(Architecture::Mips64el),
-            "mipsel" => Ok(Architecture::Mipsel),
-            "powerpc" => Ok(Architecture::PowerPC),
-            "ppc64" => Ok(Architecture::Ppc64),
-            "ppc64el" => Ok(Architecture::Ppc64el),
-            "riscv64" => Ok(Architecture::Riscv64),
-            "s390x" => Ok(Architecture::S390x),
-            "sh4" => Ok(Architecture::Sh4),
-            "sparc64" => Ok(Architecture::Sparc64),
-            "x32" => Ok(Architecture::X32),
-            "source" => Ok(Architecture::Source),
+            "all" => Ok(Self::All),
+            "alpha" => Ok(Self::Alpha),
+            "amd64" => Ok(Self::Amd64),
+            "arc" => Ok(Self::Arc),
+            "arm64" => Ok(Self::Arm64),
+            "armel" => Ok(Self::Armel),
+            "armhf" => Ok(Self::Armhf),
+            "hppa" => Ok(Self::Hppa),
+            "hurd-amd64" => Ok(Self::HurdAmd64),
+            "hurd-i386" => Ok(Self::HurdI386),
+            "i386" => Ok(Self::I386),
+            "ia64" => Ok(Self::Ia64),
+            "loong64" => Ok(Self::Loong64),
+            "m68k" => Ok(Self::M68k),
+            "mips64el" => Ok(Self::Mips64el),
+            "mipsel" => Ok(Self::Mipsel),
+            "powerpc" => Ok(Self::PowerPC),
+            "ppc64" => Ok(Self::Ppc64),
+            "ppc64el" => Ok(Self::Ppc64el),
+            "riscv64" => Ok(Self::Riscv64),
+            "s390x" => Ok(Self::S390x),
+            "sh4" => Ok(Self::Sh4),
+            "sparc64" => Ok(Self::Sparc64),
+            "x32" => Ok(Self::X32),
+            "source" => Ok(Self::Source),
             _ => Err(ParseError::InvalidArchitecture),
         }
     }
